Structs
- Custom
Effect Descriptor V1 - Descriptor used to register a bounded custom effect (v1).
- Custom
Effect Descriptor V2 - Descriptor used to register a bounded custom effect (v2).
- Custom
Effect Descriptor V3 - Descriptor used to register a bounded custom effect (v3).
Enums
Traits
- Custom
Effect Service - Renderer-owned registry for bounded custom effects.