pub struct AppWindowId(/* private fields */);Trait Implementations
Sourceimpl Clone for AppWindowId
impl Clone for AppWindowId
Sourcefn clone(&self) -> AppWindowId
fn clone(&self) -> AppWindowId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AppWindowId
impl Debug for AppWindowId
Sourceimpl Default for AppWindowId
impl Default for AppWindowId
Sourcefn default() -> AppWindowId
fn default() -> AppWindowId
Returns the “default value” for a type. Read more
Sourceimpl From<KeyData> for AppWindowId
impl From<KeyData> for AppWindowId
Sourceimpl Hash for AppWindowId
impl Hash for AppWindowId
Sourceimpl Key for AppWindowId
impl Key for AppWindowId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for AppWindowId
impl Ord for AppWindowId
Sourcefn cmp(&self, other: &AppWindowId) -> Ordering
fn cmp(&self, other: &AppWindowId) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AppWindowId
impl PartialEq for AppWindowId
Sourceimpl PartialOrd for AppWindowId
impl PartialOrd for AppWindowId
impl Copy for AppWindowId
impl Eq for AppWindowId
impl StructuralPartialEq for AppWindowId