pub struct DockNodeId(/* private fields */);Trait Implementations
Sourceimpl Clone for DockNodeId
impl Clone for DockNodeId
Sourcefn clone(&self) -> DockNodeId
fn clone(&self) -> DockNodeId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DockNodeId
impl Debug for DockNodeId
Sourceimpl Default for DockNodeId
impl Default for DockNodeId
Sourcefn default() -> DockNodeId
fn default() -> DockNodeId
Returns the “default value” for a type. Read more
Sourceimpl From<KeyData> for DockNodeId
impl From<KeyData> for DockNodeId
Sourceimpl Hash for DockNodeId
impl Hash for DockNodeId
Sourceimpl Key for DockNodeId
impl Key for DockNodeId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for DockNodeId
impl Ord for DockNodeId
Sourcefn cmp(&self, other: &DockNodeId) -> Ordering
fn cmp(&self, other: &DockNodeId) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DockNodeId
impl PartialEq for DockNodeId
Sourceimpl PartialOrd for DockNodeId
impl PartialOrd for DockNodeId
impl Copy for DockNodeId
impl Eq for DockNodeId
impl StructuralPartialEq for DockNodeId