pub struct EffectId(/* private fields */);Trait Implementations
Sourceimpl Key for EffectId
impl Key for EffectId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for EffectId
impl Ord for EffectId
Sourceimpl PartialOrd for EffectId
impl PartialOrd for EffectId
impl Copy for EffectId
impl Eq for EffectId
impl StructuralPartialEq for EffectId