pub struct ImageId(/* private fields */);Trait Implementations
Sourceimpl Key for ImageId
impl Key for ImageId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for ImageId
impl Ord for ImageId
Sourceimpl PartialOrd for ImageId
impl PartialOrd for ImageId
impl Copy for ImageId
impl Eq for ImageId
impl StructuralPartialEq for ImageId