pub struct MaterialId(/* private fields */);Trait Implementations
Sourceimpl Clone for MaterialId
impl Clone for MaterialId
Sourcefn clone(&self) -> MaterialId
fn clone(&self) -> MaterialId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MaterialId
impl Debug for MaterialId
Sourceimpl Default for MaterialId
impl Default for MaterialId
Sourcefn default() -> MaterialId
fn default() -> MaterialId
Returns the “default value” for a type. Read more
Sourceimpl From<KeyData> for MaterialId
impl From<KeyData> for MaterialId
Sourceimpl Hash for MaterialId
impl Hash for MaterialId
Sourceimpl Key for MaterialId
impl Key for MaterialId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for MaterialId
impl Ord for MaterialId
Sourcefn cmp(&self, other: &MaterialId) -> Ordering
fn cmp(&self, other: &MaterialId) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MaterialId
impl PartialEq for MaterialId
Sourceimpl PartialOrd for MaterialId
impl PartialOrd for MaterialId
impl Copy for MaterialId
impl Eq for MaterialId
impl StructuralPartialEq for MaterialId