pub struct PathId(/* private fields */);Trait Implementations
Sourceimpl Key for PathId
impl Key for PathId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for PathId
impl Ord for PathId
Sourceimpl PartialOrd for PathId
impl PartialOrd for PathId
impl Copy for PathId
impl Eq for PathId
impl StructuralPartialEq for PathId