pub struct RenderTargetId(/* private fields */);Trait Implementations
Sourceimpl Clone for RenderTargetId
impl Clone for RenderTargetId
Sourcefn clone(&self) -> RenderTargetId
fn clone(&self) -> RenderTargetId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RenderTargetId
impl Debug for RenderTargetId
Sourceimpl Default for RenderTargetId
impl Default for RenderTargetId
Sourcefn default() -> RenderTargetId
fn default() -> RenderTargetId
Returns the “default value” for a type. Read more
Sourceimpl From<KeyData> for RenderTargetId
impl From<KeyData> for RenderTargetId
Sourceimpl Hash for RenderTargetId
impl Hash for RenderTargetId
Sourceimpl Key for RenderTargetId
impl Key for RenderTargetId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for RenderTargetId
impl Ord for RenderTargetId
Sourcefn cmp(&self, other: &RenderTargetId) -> Ordering
fn cmp(&self, other: &RenderTargetId) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RenderTargetId
impl PartialEq for RenderTargetId
Sourceimpl PartialOrd for RenderTargetId
impl PartialOrd for RenderTargetId
impl Copy for RenderTargetId
impl Eq for RenderTargetId
impl StructuralPartialEq for RenderTargetId