pub struct SvgId(/* private fields */);Trait Implementations
Sourceimpl Key for SvgId
impl Key for SvgId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for SvgId
impl Ord for SvgId
Sourceimpl PartialOrd for SvgId
impl PartialOrd for SvgId
impl Copy for SvgId
impl Eq for SvgId
impl StructuralPartialEq for SvgId