pub struct TextBlobId(/* private fields */);Trait Implementations
Sourceimpl Clone for TextBlobId
impl Clone for TextBlobId
Sourcefn clone(&self) -> TextBlobId
fn clone(&self) -> TextBlobId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TextBlobId
impl Debug for TextBlobId
Sourceimpl Default for TextBlobId
impl Default for TextBlobId
Sourcefn default() -> TextBlobId
fn default() -> TextBlobId
Returns the “default value” for a type. Read more
Sourceimpl From<KeyData> for TextBlobId
impl From<KeyData> for TextBlobId
Sourceimpl Hash for TextBlobId
impl Hash for TextBlobId
Sourceimpl Key for TextBlobId
impl Key for TextBlobId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for TextBlobId
impl Ord for TextBlobId
Sourcefn cmp(&self, other: &TextBlobId) -> Ordering
fn cmp(&self, other: &TextBlobId) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TextBlobId
impl PartialEq for TextBlobId
Sourceimpl PartialOrd for TextBlobId
impl PartialOrd for TextBlobId
impl Copy for TextBlobId
impl Eq for TextBlobId
impl StructuralPartialEq for TextBlobId