pub enum EffectStep {
Show 13 variants
GaussianBlur {
radius_px: Px,
downsample: u32,
},
DropShadowV1(DropShadowV1),
BackdropWarpV1(BackdropWarpV1),
BackdropWarpV2(BackdropWarpV2),
NoiseV1(NoiseV1),
ColorAdjust {
saturation: f32,
brightness: f32,
contrast: f32,
},
ColorMatrix {
m: [f32; 20],
},
AlphaThreshold {
cutoff: f32,
soft: f32,
},
Pixelate {
scale: u32,
},
Dither {
mode: DitherMode,
},
CustomV1 {
id: EffectId,
params: EffectParamsV1,
max_sample_offset_px: Px,
},
CustomV2 {
id: EffectId,
params: EffectParamsV1,
max_sample_offset_px: Px,
input_image: Option<CustomEffectImageInputV1>,
},
CustomV3 {
id: EffectId,
params: EffectParamsV1,
max_sample_offset_px: Px,
user0: Option<CustomEffectImageInputV1>,
user1: Option<CustomEffectImageInputV1>,
sources: CustomEffectSourcesV3,
},
}Variants
GaussianBlur
DropShadowV1(DropShadowV1)
BackdropWarpV1(BackdropWarpV1)
BackdropWarpV2(BackdropWarpV2)
NoiseV1(NoiseV1)
ColorAdjust
ColorMatrix
AlphaThreshold
Pixelate
Dither
Fields
mode: DitherModeCustomV1
Fields
params: EffectParamsV1max_sample_offset_px: PxMaximum sampling offset (in logical px) that the custom effect may use when reading from its source texture.
This is a bounded contract input used by renderers to deterministically allocate enough context (“padding”) for effect chains (e.g. blur -> custom refraction) without introducing edge artifacts near clipped/scissored bounds.
Backends may clamp or degrade behavior under tight budgets.
CustomV2
Fields
params: EffectParamsV1max_sample_offset_px: PxMaximum sampling offset (in logical px) that the custom effect may use when reading from its source texture.
This preserves the deterministic chain padding story from v1.
input_image: Option<CustomEffectImageInputV1>Optional user-provided image input (v2 ceiling bump).
CustomV3
Fields
params: EffectParamsV1max_sample_offset_px: PxMaximum sampling offset (in logical px) that the custom effect may use when reading from its source textures.
This preserves the deterministic chain padding story from v1/v2.
user0: Option<CustomEffectImageInputV1>Optional user-provided image input 0 (v2-compatible).
user1: Option<CustomEffectImageInputV1>Optional user-provided image input 1 (v3 ceiling bump).
sources: CustomEffectSourcesV3Renderer-provided sources request (raw + optional pyramid).
Implementations
Sourceimpl EffectStep
impl EffectStep