WarpMapEncodingV1

Enum WarpMapEncodingV1 

pub enum WarpMapEncodingV1 {
    RgSigned,
    NormalRgb,
}

Variants



RgSigned

Decode displacement from RG in [0, 1] mapped to [-1, 1].

This is a good default for authored displacement maps.



NormalRgb

Decode a normal from RGB in [0, 1] mapped to [-1, 1], and use XY as displacement.

This is convenient when the warp field is stored as a normal map.