SceneRecording

Struct SceneRecording 

pub struct SceneRecording { /* private fields */ }

Implementations

Source

impl SceneRecording

pub fn replay_ops(&mut self, ops: &[SceneOp])

pub fn replay_ops_translated(&mut self, ops: &[SceneOp], delta: Point)

pub fn replay_ops_transformed( &mut self, ops: &[SceneOp], transform: Transform2D, )

Source

impl SceneRecording

pub fn push_shadow_rrect_quad_fallback(&mut self, spec: ShadowRRectFallbackSpec)

Replay the deterministic quad fallback for a rounded-rect shadow primitive into this scene.

Source

impl SceneRecording

Source

impl SceneRecording

pub fn clear(&mut self)

pub fn push(&mut self, op: SceneOp)

pub fn with_transform<T>( &mut self, transform: Transform2D, f: impl FnOnce(&mut Self) -> T, ) -> T

pub fn with_opacity<T>( &mut self, opacity: f32, f: impl FnOnce(&mut Self) -> T, ) -> T

pub fn with_layer<T>(&mut self, layer: u32, f: impl FnOnce(&mut Self) -> T) -> T

pub fn with_clip_rect<T>( &mut self, rect: Rect, f: impl FnOnce(&mut Self) -> T, ) -> T

pub fn with_clip_rrect<T>( &mut self, rect: Rect, corner_radii: Corners, f: impl FnOnce(&mut Self) -> T, ) -> T

pub fn with_clip_path<T>( &mut self, bounds: Rect, origin: Point, path: PathId, f: impl FnOnce(&mut Self) -> T, ) -> T

pub fn with_mask<T>( &mut self, bounds: Rect, mask: Mask, f: impl FnOnce(&mut Self) -> T, ) -> T

pub fn with_effect<T>( &mut self, bounds: Rect, mode: EffectMode, chain: EffectChain, quality: EffectQuality, f: impl FnOnce(&mut Self) -> T, ) -> T

pub fn with_composite_group<T>( &mut self, desc: CompositeGroupDesc, f: impl FnOnce(&mut Self) -> T, ) -> T

pub fn with_backdrop_source_group_v1<T>( &mut self, bounds: Rect, pyramid: Option<CustomEffectPyramidRequestV1>, quality: EffectQuality, f: impl FnOnce(&mut Self) -> T, ) -> T

pub fn ops(&self) -> &[SceneOp]

pub fn ops_len(&self) -> usize

pub fn swap_storage( &mut self, other_ops: &mut Vec<SceneOp>, other_fingerprint: &mut u64, )

Swap the internal op storage with an external buffer.

This is a performance-oriented API used by subsystems like the UI paint cache to “take” the previous frame’s ops without copying.

In debug builds, this asserts if called more than once without an intervening clear(), because repeated swaps typically indicate multiple paint-cache ingestions from the same scene.

pub fn fingerprint(&self) -> u64