SemanticsRole

Enum SemanticsRole 

#[non_exhaustive]
pub enum SemanticsRole {
Show 44 variants Generic, Window, Panel, Group, Region, Toolbar, Heading, Dialog, AlertDialog, Alert, Status, Log, Button, Link, Image, Checkbox, Switch, Slider, SpinButton, ProgressBar, Meter, ScrollBar, Splitter, ComboBox, RadioGroup, RadioButton, TabList, Tab, TabPanel, MenuBar, Menu, MenuItem, MenuItemCheckbox, MenuItemRadio, Tooltip, Text, TextField, List, ListItem, Separator, ListBox, ListBoxOption, TreeItem, Viewport,
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Generic



Window



Panel



Group



Region

A landmark region.

This is primarily used to model ARIA role="region" outcomes in ports of DOM-first component libraries (e.g. Radix Accordion content panels).



Toolbar



Heading



Dialog



AlertDialog



Alert



Status

A non-interactive advisory live region (ARIA role="status").



Log

A chronological stream of advisory updates (ARIA role="log").



Button



Image



Checkbox



Switch



Slider



SpinButton



ProgressBar



Meter



ScrollBar



Splitter



ComboBox



RadioGroup



RadioButton



TabList



Tab



TabPanel



MenuBar



Menu



MenuItem



MenuItemCheckbox



MenuItemRadio



Tooltip



Text



TextField



List



ListItem



Separator



ListBox



ListBoxOption



TreeItem



Viewport