pub struct TextShapingStyle {
pub font: Option<FontId>,
pub weight: Option<FontWeight>,
pub slant: Option<TextSlant>,
pub letter_spacing_em: Option<f32>,
pub features: Vec<TextFontFeatureSetting>,
pub axes: Vec<TextFontAxisSetting>,
}Fields
font: Option<FontId>weight: Option<FontWeight>slant: Option<TextSlant>letter_spacing_em: Option<f32>features: Vec<TextFontFeatureSetting>Explicit OpenType feature overrides (best-effort).
This is intended for editor-grade text surfaces (e.g. ligature policy in code) and diagnostics. Callers should treat this as best-effort: if the resolved face does not support a requested tag, it will be ignored by shaping backends.
axes: Vec<TextFontAxisSetting>Explicit variable font axis overrides.
This is an advanced surface intended for code editors and diagnostics. Callers should treat this as best-effort: if the requested axis is not supported by the resolved font face, it will be ignored by the shaping backend.
Implementations
Sourceimpl TextShapingStyle
impl TextShapingStyle
pub fn with_font(self, font: FontId) -> Self
pub fn with_weight(self, weight: FontWeight) -> Self
pub fn with_slant(self, slant: TextSlant) -> Self
pub fn with_letter_spacing_em(self, letter_spacing_em: f32) -> Self
pub fn with_axis(self, tag: impl Into<String>, value: f32) -> Self
pub fn with_feature(self, tag: impl Into<String>, value: u32) -> Self