SemanticsFlags

Struct SemanticsFlags 

pub struct SemanticsFlags {
Show 17 fields pub focused: bool, pub captured: bool, pub disabled: bool, pub read_only: bool, pub hidden: bool, pub visited: bool, pub multiselectable: bool, pub live: Option<SemanticsLive>, pub live_atomic: bool, pub selected: bool, pub expanded: bool, pub checked: Option<bool>, pub checked_state: Option<SemanticsCheckedState>, pub pressed_state: Option<SemanticsPressedState>, pub required: bool, pub invalid: Option<SemanticsInvalid>, pub busy: bool,
}

Fields

focused: boolcaptured: booldisabled: boolread_only: boolhidden: bool

Exclude this node (and its subtree) from the accessibility tree presented to assistive technologies.

This is a portable approximation of ARIA aria-hidden.

visited: bool

Indicates that a link has been visited.

This is a portable approximation of the “visited link” concept in HTML.

multiselectable: bool

Indicates that this collection supports selecting multiple items.

This is a portable approximation of ARIA aria-multiselectable.

live: Option<SemanticsLive>

When set, indicates that this node is a live region (ARIA aria-live).

None means no live region semantics are requested.

live_atomic: bool

When true, indicates that updates to this live region should be presented atomically (ARIA aria-atomic).

selected: boolexpanded: boolchecked: Option<bool>

Legacy binary checked state.

Prefer checked_state for tri-state widgets.

checked_state: Option<SemanticsCheckedState>

Tri-state checked state (None = not checkable / unknown).

pressed_state: Option<SemanticsPressedState>

Tri-state pressed state for toggle-button-like widgets (None = not a toggle / unknown).

required: bool

Indicates that a form field is required to be filled in.

invalid: Option<SemanticsInvalid>

Indicates that a form control has invalid input.

busy: bool

Indicates that this node (and typically its subtree) is currently busy (e.g. loading).

This is a portable approximation of ARIA aria-busy.