pub struct ViewportMapping {
pub content_rect: Rect,
pub target_px_size: (u32, u32),
pub fit: ViewportFit,
}Fields
content_rect: Recttarget_px_size: (u32, u32)fit: ViewportFitImplementations
Sourceimpl ViewportMapping
impl ViewportMapping
pub fn map(self) -> ViewportMapped
Sourcepub fn target_px_per_screen_px(self) -> Option<f32>
pub fn target_px_per_screen_px(self) -> Option<f32>
Returns the scale from window-local logical pixels (“screen px”) to render-target pixels.
This is derived from the mapped draw rect (logical pixels) and the backing render target
size self.target_px_size (physical pixels).
For ViewportFit::Contain/Cover this is uniform; for ViewportFit::Stretch the mapping
is non-uniform, so this returns the smaller axis scale as a conservative approximation for
isotropic thresholds (hit radii, click distances).
pub fn window_point_to_uv(self, p: Point) -> Option<(f32, f32)>
pub fn window_point_to_uv_clamped(self, p: Point) -> (f32, f32)
pub fn window_point_to_target_px(self, p: Point) -> Option<(u32, u32)>
pub fn window_point_to_target_px_clamped(self, p: Point) -> (u32, u32)